from rich.padding import Padding
from rich.table import Table
from rich import box
from textual.widget import Widget


class SelectQuestionTable(Widget):
    def __init__(
        self,
        all_topics,
    ):
        super().__init__()
        self.all_topics = all_topics
        self.current_topic = None
        self.key_topic_map = {
            str(key): topic for key, topic in enumerate(self.all_topics, 1)
        }

    def render(self):
        topics_table = Table(box=box.SIMPLE, min_width=50)
        topics_table.add_column("Номер", justify="center", no_wrap=True)
        topics_table.add_column("Тема", justify="left")
        for key, topic in self.key_topic_map.items():
            if self.current_topic and key == self.current_topic:
                topics_table.add_row(key, topic, style="black on white")
            else:
                topics_table.add_row(key, topic)

        main_table = Table(expand=True, show_header=False, box=None)
        main_table.add_row("Выберите тему и нажмите Enter")
        main_table.add_row(topics_table)
        if self.current_topic and self.current_topic not in self.key_topic_map:
            main_table.add_row(
                f"Выберите вопросы из диапазона {', '.join(self.key_topic_map)}.\n"
                f"Нажмите Enter чтобы сбить введенные числа",
                style="black on red",
            )
        main_table.add_row("Для выхода из программы нажмите ctrl-q")
        return Padding(main_table, 3)

    async def update(self, selected_topic):
        self.current_topic = selected_topic
        self.refresh()



from rich.text import Text

from textual.widget import Widget
from textual.widgets import Footer


class HelpTable(Footer):
    def __init__(self):
        super().__init__()
        self.long_description = False

    def make_key_text(self) -> Text:
        """Create text containing all the keys."""
        text = Text(
            style="black on green",
            no_wrap=True,
            overflow="ellipsis",
            justify="left",
            end="",
        )
        for binding in self.app.bindings.shown_keys:
            key = binding.key
            key_display = (
                binding.key_display if binding.key_display else binding.description
            )
            description = key_display if self.long_description else binding.description
            hovered = self.highlight_key == binding.key
            key_text = Text.assemble(
                (f" {key} ", "reverse" if hovered else "default on default"),
                f" {description} ",
                meta={"@click": f"app.press('{binding.key}')", "key": binding.key},
            )
            text.append_text(key_text)
        return text

    async def toggle(self):
        self.long_description = not self.long_description
        self._key_text = self.make_key_text()
        self.refresh()

    def render(self):
        if self._key_text is None:
            self._key_text = self.make_key_text()
        return self._key_text
